@@ -1,5 +1,5 @@
 <?php
-$allpages = getAllSystemNames ();
+$allpages = getAllSlugs ();
 if (containsModule ( get_requested_pagename (), "random_page" ) or isset ( $_GET ["view_random_page"] )) {
 	$random = null;
 	do {
